@@ -13,6 +13,7 @@
 // KF
 #include <KLocalizedString>
 #include <KLocalizedContext>
+#include <KQuickIconProvider>
 // Qt
 #include <QQmlContext>
 #include <QStandardPaths>
@@ -28,6 +29,9 @@ KReversiView::KReversiView(KReversiGame* game, QWidget *parent, KgThemeProvider
 {
     QQmlEngine *engine = this->engine();
 
+    // setup ImageProvider for KIconTheme icons
+    engine->addImageProvider(QStringLiteral("icon"), new KQuickIconProvider);
+
     auto *localizedContextObject = new KLocalizedContext(engine);
     engine->rootContext()->setContextObject(localizedContextObject);
 
